You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@pdfbox.apache.org by "Alfred (Jira)" <ji...@apache.org> on 2020/06/11 07:29:00 UTC
[jira] [Comment Edited] (PDFBOX-4877) Matrix class performance
improvements
[ https://issues.apache.org/jira/browse/PDFBOX-4877?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=17133004#comment-17133004 ]
Alfred edited comment on PDFBOX-4877 at 6/11/20, 7:28 AM:
----------------------------------------------------------
I wrote a simplistic test that performs 100M multiplication and pre-multiplication operations.
The original time was 4200ms. The new version takes 2200ms.
[^PDFBOX-4877.patch]
Review: [https://diffy.org/diff/3jejf17dj3ambrrk8yp5app66r]
was (Author: faltiska):
I wrote a simplistic test theat performs 100M multiplication and pre-multiplication operations.
The original time was 4200ms. The new version takes 2200ms.
[^PDFBOX-4877.patch]
Review: https://diffy.org/diff/3jejf17dj3ambrrk8yp5app66r
> Matrix class performance improvements
> -------------------------------------
>
> Key: PDFBOX-4877
> URL: https://issues.apache.org/jira/browse/PDFBOX-4877
> Project: PDFBox
> Issue Type: Improvement
> Components: Parsing, Text extraction
> Affects Versions: 2.0.20, 3.0.0 PDFBox
> Reporter: Alfred
> Priority: Major
> Labels: Optimization
> Attachments: PDFBOX-4877.patch
>
> Original Estimate: 1m
> Remaining Estimate: 1m
>
> I am testing text extraction from PDF and profiling the execution.
> I found that the third major time consumer is with matrix multiplicaitons.
> The Matrix class spends large amounts of time copying results to new instances.
--
This message was sent by Atlassian Jira
(v8.3.4#803005)
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@pdfbox.apache.org
For additional commands, e-mail: dev-help@pdfbox.apache.org